# Primate Python Package

Python integration for the Primate web framework.

## Installation

```sh
pip install primate-run
```

## Quickstart

```py
from primate import Route

   @Route.get
   def hello(request):
       return "Hello World!"
```
